unit demorichform;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, ExtCtrls;

type
  TPDemoRichForm = class(TForm)
    Panel1: TPanel;
    RichEdit: TRichEdit;
    Label1: TLabel;
    btPrint: TButton;
    btPreview: TButton;
    procedure FormCreate(Sender: TObject);
    procedure btPrintClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  PDemoRichForm: TPDemoRichForm;

implementation

{$R *.DFM}

uses demoform, skuprinttext;

procedure TPDemoRichForm.FormCreate(Sender: TObject);
begin
  richedit.lines.loadfromfile('sample rich text.rtf');
end;

procedure TPDemoRichForm.btPrintClick(Sender: TObject);
var
  svMode: TSKUPptWrapMode;
begin
  //We reuse the components printdialog and printtext from the main form
  //In a real application, it is better to create a data module for sharing
  //such components. This is just a hint to create good code.
  if not pdemoform.PrintDialog.Execute then
    exit;
  pdemoform.printtext.HeaderRight := DateToStr(Date) + ' ' + TimeToStr(Time);
  pdemoform.printtext.Title := 'Printing from RichEdit control';
  pdemoform.printtext.footer := 'sample rich text.rtf';
  pdemoform.printtext.startPage := pdemoform.PrintDialog.fromPage;
  pdemoform.printtext.endPage := pdemoform.PrintDialog.toPage;
  //The following nested try structure is
  //most convenient for using TSKUPrintText
  //Note how we preserve the original wrapMode
  //and restore it
  svMode := pdemoform.printtext.wrapMode;
  try
    try
        if sender=btPreview then
          pdemoform.printtext.isPreview := true;
        pdemoform.printtext.openPrinter;

        //print our comments
        //We want to print comments word-wrapped
        pdemoform.printtext.wrapMode := pptWordWrap;
        pdemoform.printtext.printALine(
        'In this example, we print the contents of the '+
        'rich edit control along with the headers and '+
        'footers that we have set up. If you want to insert '+
        'the comments like these in rich text, create a '+
        'hidden richedit control, load it with rtf text '+
        'and then print it before you print the actual '+
        'rich edit. There are numerous possibilities. '+
        'TSKUPrintText gives you all the flexibility!');
        pdemoform.printtext.skiplines(2);
        //restore the original wrap mode
        pdemoform.printtext.wrapMode := svMode;

        pdemoform.printtext.printARichEdit(richedit);
    except
        on E:exception do
        begin
          //Exception occurs in three cases:
          // 1. Genuine errors: hadErrors is true
          // 2. Printing cancelled: printCancelled is true
          // 3. 'To' page specified is finished. This is
          //    just to get out of printing and is normal.
          //    So hadErrors is false.
          //Usually, we want to give message only on had
          //Errors
          if pdemoform.printtext.hadErrors then
            showMessage(E.Message);
        end;
    end; //inner try
  finally
      pdemoform.printtext.wrapMode := svMode;
      pdemoform.printtext.closeprinter;
      if (sender = btPreview) and
        (not pdemoform.printtext.hadErrors) and (not pdemoform.printtext.printCancelled)
      then
        pdemoform.printtext.showPreview;
  end;
end;

end.
